==> vardoc-8.x-2.1-core.tar.gz: vardoc-8.x-2.1/profiles/vardoc/README.md <==
[![Build Status](https://travis-ci.org/Vardot/vardoc.svg?branch=8.x-2.1)](https://travis-ci.org/Vardot/vardoc/builds/450837777) Vardoc 8.2.1
# Vardoc: Knowledge Base System and Documentation Site

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Vardoc%20-%20No%20Padding.png)](https://www.drupal.org/project/vardoc)

## Built Using [Varbase](https://www.drupal.org/project/varbase)
This distribution is built using Varbase, the base distribution delivered
 to you by [Vardot](https://www.vardot.com).
Learn more about [Varbase](https://www.drupal.org/project/varbase) and how
 you can build your own distribution on top
 of Varbase here: [http://docs.varbase.vardot.com](http://docs.varbase.vardot.com)

## About Vardoc
Vardoc is a knowledge base system, a wiki system, and a documentation management
 system designed to host massive amount of content in a structured and
 easy-to-find format. Vardoc helps you build a connected organization,
 product, or knowledge area to allow everyone involved to find the answers
 they seek, and contribute their expertise in the knowledge base.

Think of it as a wiki site of your product, user manuals, or organizational
 processes. With easy structure, collaborative tools, and friendly design.

[![](https://www.drupal.org/files/project-images/vardoc-mockup.png)](https://www.drupal.org/project/vardoc)

Built on top of Varbase, the open source Drupal 8 distribution, Vardoc provides
 powerful functional features such as editorial features, search function,
 taxonomy, user management, and customizable themes. It also delivers
 top-notch non-functional requirements such as enterprise security,
 fast performance, search engine optimization (SEO), accessibility
 compliance, and many more features.

[![](https://www.drupal.org/files/vardoc-mockup-2.jpg)](https://www.drupal.org/project/vardoc)

Our goal is to bring ease to you when writing and creating a documentation
 for your product, website, departmental processes, online manuals,
 or your enterprise as whole.

## Who Can Benefit From Vardoc?
* Product documentation sites.
* Agencies who want to document software.
* Documentation for Open Source products/projects.
* Organizations who want to document their processes.
* Online user manuals.

## Install or Try it Yourself
# [Try on Simplytest.me](https://simplytest.me/project/vardoc)

## Or install it via Composer:

# Install with Composer

To install the most recent stable release of Vardoc 8.2.x run this command:
```
composer create-project Vardot/vardoc-project:^8.2.1 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Vardoc 8.2.x run this command:
```
composer create-project vardot/vardoc-project:8.2.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

# [Install with Composer](https://github.com/Vardot/vardoc-project)

Built using [Varbase](https://www.drupal.org/project/varbase), the base
 distribution delivered to you by [Vardot](https://www.vardot.com)

This distribution is sponsored and developed by [Vardot](https://www.vardot.com).
Initial building, ongoing maintenance and development.


## [Automated Functional Testing](https://github.com/Vardot/vardoc/blob/8.x-2.x/tests/README.md)

## [Vardoc Gherkin features](https://github.com/Vardot/vardoc/blob/8.x-2.x/tests/features/vardoc/README.md)

## [Varbase 8.4.x Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Vardoc](https://github.com/Vardot/vardoc/blob/8.x-2.x/CHANGELOG.md)

## [General instructions on how to update Vardoc](https://github.com/Vardot/vardoc/blob/8.x-2.x/UPDATE.md)

==> vardoc-8.x-2.2-core.tar.gz: vardoc-8.x-2.2/profiles/vardoc/README.md <==
[![Build Status](https://travis-ci.org/Vardot/vardoc.svg?branch=8.x-2.2)](https://travis-ci.org/Vardot/vardoc/builds/456583110) Vardoc 8.2.2
# Vardoc: Knowledge Base System and Documentation Site

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Vardoc%20-%20No%20Padding.png)](https://www.drupal.org/project/vardoc)

## Built Using [Varbase](https://www.drupal.org/project/varbase)
This distribution is built using Varbase, the base distribution delivered
 to you by [Vardot](https://www.vardot.com).
Learn more about [Varbase](https://www.drupal.org/project/varbase) and how
 you can build your own distribution on top
 of Varbase here: [http://docs.varbase.vardot.com](http://docs.varbase.vardot.com)

## About Vardoc
Vardoc is a knowledge base system, a wiki system, and a documentation management
 system designed to host massive amount of content in a structured and
 easy-to-find format. Vardoc helps you build a connected organization,
 product, or knowledge area to allow everyone involved to find the answers
 they seek, and contribute their expertise in the knowledge base.

Think of it as a wiki site of your product, user manuals, or organizational
 processes. With easy structure, collaborative tools, and friendly design.

[![](https://www.drupal.org/files/project-images/vardoc-mockup.png)](https://www.drupal.org/project/vardoc)

Built on top of Varbase, the open source Drupal 8 distribution, Vardoc provides
 powerful functional features such as editorial features, search function,
 taxonomy, user management, and customizable themes. It also delivers
 top-notch non-functional requirements such as enterprise security,
 fast performance, search engine optimization (SEO), accessibility
 compliance, and many more features.

[![](https://www.drupal.org/files/vardoc-mockup-2.jpg)](https://www.drupal.org/project/vardoc)

Our goal is to bring ease to you when writing and creating a documentation
 for your product, website, departmental processes, online manuals,
 or your enterprise as whole.

## Who Can Benefit From Vardoc?
* Product documentation sites.
* Agencies who want to document software.
* Documentation for Open Source products/projects.
* Organizations who want to document their processes.
* Online user manuals.

## Install or Try it Yourself
# [Try on Simplytest.me](https://simplytest.me/project/vardoc)

## Or install it via Composer:

# Install with Composer

To install the most recent stable release of Vardoc 8.2.x run this command:
```
composer create-project Vardot/vardoc-project:8.2.2 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Vardoc 8.2.x run this command:
```
composer create-project vardot/vardoc-project:8.2.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

# [Install with Composer](https://github.com/Vardot/vardoc-project)

Built using [Varbase](https://www.drupal.org/project/varbase), the base
 distribution delivered to you by [Vardot](https://www.vardot.com)

This distribution is sponsored and developed by [Vardot](https://www.vardot.com).
Initial building, ongoing maintenance and development.


## [Automated Functional Testing](https://github.com/Vardot/vardoc/blob/8.x-2.x/tests/README.md)

## [Vardoc Gherkin features](https://github.com/Vardot/vardoc/blob/8.x-2.x/tests/features/vardoc/README.md)

## [Varbase Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Vardoc](https://github.com/Vardot/vardoc/blob/8.x-2.x/CHANGELOG.md)

## [General instructions on how to update Vardoc](https://github.com/Vardot/vardoc/blob/8.x-2.x/UPDATE.md)
